@@ -1,6 +1,6 @@
 package Getopt::EX::Hashed;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Getopt::EX::Hashed - Hash store object automation for Getopt::Long
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =head1 SYNOPSIS
 
@@ -211,6 +211,10 @@ sub _accessor {
 	rw => sub {
 	    $#_ and do { $_[0]->{$name} = $_[1]; return $_[0] };
 	    $_[0]->{$name};
+	},
+	lv => sub :lvalue {
+	    $#_ and do { $_[0]->{$name} = $_[1]; return $_[0] };
+	    $_[0]->{$name};
 	}
     }->{$is} or die "$name has invalid 'is' parameter.\n";
 }
@@ -429,10 +433,11 @@ There is no difference with ones in C<spec> parameter.
 
     has start => "=i", alias => "s begin";
 
-=item B<is> => C<ro> | C<rw>
+=item B<is> => C<ro> | C<rw> | C<lv>
 
 To produce accessor method, C<is> parameter is necessary.  Set the
-value C<ro> for read-only, C<rw> for read-write.
+value C<ro> for read-only, C<rw> for read-write.  If C<lv> is given,
+that member is read-write and can be assigned as lvalue.
 
 If you want to make accessor for all following members, use
 C<configure> and set C<DEFAULT> parameter.
@@ -463,7 +468,7 @@ is the first parameter.
 When called, hash object is passed as C<$_>.
 
     has [ qw(left right both) ] => '=i';
-    has "+both" => action => sub {
+    has "+both" => sub {
         $_->{left} = $_->{right} = $_[1];
     };
 
@@ -471,14 +476,14 @@ You can use this for C<< "<>" >> to catch everything.  In that case,
 spec parameter does not matter and not required.
 
     has ARGV => default => [];
-    has "<>" => action => sub {
+    has "<>" => sub {
         push @{$_->{ARGV}}, $_[0];
     };
 
 =back
 
 Following parameters are all for data validation.  First C<must> is a
-generic validator and can implement anything.  Others are shorthand
+generic validator and can implement anything.  Others are shortcut
 for common rules.
 
 =over 7
@@ -653,7 +658,7 @@ The following copyright notice applies to all the files provided in
 this distribution, including binary files, unless explicitly noted
 otherwise.
 
-Copyright 2021 Kazumasa Utashiro
+Copyright 2021-2022 Kazumasa Utashiro
 
 =head1 LICENSE
 
